@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
-our $DATE = '2015-06-18'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2015-06-19'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -254,7 +254,7 @@ sub gen_inline_pericmd_script {
             map {$_ => _get_module($_)} (
                 "Data::Check::Structure",
                 "Text::Table::Tiny",
-                "Getopt::Long::Less",
+                "Getopt::Long::EvenLess",
                 @{ $args{include} // [] },
             )
         },
@@ -270,9 +270,20 @@ sub gen_inline_pericmd_script {
         {
             require Perinci::CmdLine::Base;
             no warnings 'once';
-            for (qw/help version json format naked_res/) {
+            for (qw/help version json format/) {
                 $copts{$_} = $Perinci::CmdLine::Base::copts{$_};
             }
+            # "naked_res!" currently not supported by Getopt::Long::EvenLess, so
+            # we split it. the downside is that we don't hide the default, by
+            # default.
+            $copts{naked_res} = {
+                getopt  => "naked-res",
+                summary => "When outputing as JSON, strip result envelope",
+            };
+            $copts{no_naked_res} = {
+                getopt  => "no-naked-res|nonaked-res",
+                summary => "When outputing as JSON, don't strip result envelope",
+            };
         }
 
         my $shebang_line;
@@ -559,7 +570,7 @@ _
         $cd->{vars}{'%_pci_args'}++;
         push @l, "# parse cmdline options\n\n";
         push @l, "{\n";
-        push @l, "require Getopt::Long::Less;\n";
+        push @l, "require Getopt::Long::EvenLess;\n";
         push @l, 'my %mentioned_args;', "\n";
         {
             push @l, 'my $go_spec = {', "\n";
@@ -593,7 +604,9 @@ _
                     } elsif ($specmeta->{common_opt} eq 'json') {
                         push @l, '        $_pci_r->{format} = (-t STDOUT) ? "json-pretty" : "json";', "\n";
                     } elsif ($specmeta->{common_opt} eq 'naked_res') {
-                        push @l, '        $_pci_r->{naked_res} = $_[1];', "\n";
+                        push @l, '        $_pci_r->{naked_res} = 1;', "\n";
+                    } elsif ($specmeta->{common_opt} eq 'no_naked_res') {
+                        push @l, '        $_pci_r->{naked_res} = 0;', "\n";
                     } else {
                         die "BUG: Unrecognized common_opt '$specmeta->{common_opt}'";
                     }
@@ -620,7 +633,7 @@ _
                 push @l, "    },\n";
             }
             push @l, "};\n";
-            push @l, 'my $res = Getopt::Long::Less::GetOptions(%$go_spec);', "\n";
+            push @l, 'my $res = Getopt::Long::EvenLess::GetOptions(%$go_spec);', "\n";
             push @l, '_pci_err([500, "GetOptions failed"]) unless $res;', "\n";
             push @l, '_pci_debug("args after GetOptions: ", \%_pci_args);', "\n" if $args{with_debug};
             push @l, '$res = _pci_check_args(\%_pci_args);', "\n";
@@ -760,7 +773,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.09 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-06-18.
+This document describes version 0.10 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-06-19.
 
 =head1 SYNOPSIS
 
@@ -786,23 +799,23 @@ B<EARLY DEVELOPMENT.>
 
 Sample startup overhead benchmark vs Perinci::CmdLine::Lite:
 
-                                     Rate  run 1 (lite) run --version (lite)    -c (lite) run 1 (inline) run --version (inline) -c (inline)   perl
- run 1 (lite)           13.1432+-0.0082/s            --               -61.4%       -82.8%         -87.7%                 -89.9%      -93.5% -97.6%
- run --version (lite)     34.029+-0.056/s 158.91+-0.45%                   --       -55.4%         -68.2%                 -74.0%      -83.3% -93.7%
- -c (lite)                 76.29+-0.095/s 480.46+-0.81%        124.19+-0.46%           --         -28.6%                 -41.6%      -62.6% -85.9%
- run 1 (inline)             106.9+-0.33/s   713.4+-2.6%          214.2+-1.1% 40.13+-0.47%             --                 -18.2%      -47.5% -80.3%
- run --version (inline)    130.68+-0.57/s   894.3+-4.4%            284+-1.8%  71.3+-0.77%   22.24+-0.65%                     --      -35.9% -75.9%
- -c (inline)                 203.8+-1.7/s     1450+-13%          498.8+-5.1%  167.1+-2.2%     90.6+-1.7%             55.9+-1.5%          -- -62.4%
- perl                        541.7+-3.4/s     4022+-26%            1492+-10%  610.1+-4.6%    406.7+-3.6%            314.5+-3.2% 165.9+-2.8%     --
+                                   Rate  run 1 (lite) run --version (lite)   -c (lite) run 1 (inline) run --version (inline) -c (inline)   perl
+ run 1 (lite)             13.59+-0.02/s            --               -61.5%      -80.8%         -87.8%                 -90.0%      -92.0% -97.5%
+ run --version (lite)   35.286+-0.053/s 159.65+-0.54%                   --      -50.2%         -68.3%                 -74.0%      -79.3% -93.6%
+ -c (lite)                70.92+-0.83/s   421.9+-6.1%            101+-2.4%          --         -36.3%                 -47.8%      -58.4% -87.1%
+ run 1 (inline)           111.31+-0.2/s   719.1+-1.9%        215.46+-0.73%    57+-1.8%             --                 -18.1%      -34.7% -79.8%
+ run --version (inline)   135.9+-0.36/s       900+-3%          285.1+-1.2%  91.6+-2.3%   22.09+-0.39%                     --      -20.2% -75.4%
+ -c (inline)               170.4+-2.9/s     1154+-21%          382.9+-8.1% 140.3+-4.9%     53.1+-2.6%             25.4+-2.1%          -- -69.1%
+ perl                      551.3+-1.9/s     3957+-15%         1462.4+-5.9% 677.4+-9.5%    395.3+-1.9%            305.7+-1.8% 223.5+-5.5%     --
  
  Average times:
-   perl                  :     1.8460ms
-   -c (inline)           :     4.9068ms
-   run --version (inline):     7.6523ms
-   run 1 (inline)        :     9.3545ms
-   -c (lite)             :    13.1079ms
-   run --version (lite)  :    29.3867ms
-   run 1 (lite)          :    76.0850ms
+   perl                  :     1.8139ms
+   -c (inline)           :     5.8685ms
+   run --version (inline):     7.3584ms
+   run 1 (inline)        :     8.9839ms
+   -c (lite)             :    14.1004ms
+   run --version (lite)  :    28.3399ms
+   run 1 (lite)          :    73.5835ms
 
 =head1 FUNCTIONS
 
